diff lisp/progmodes/cmacexp.el @ 39083:ed83c694507e

(c-macro-preprocessor): Use "gcc -E" for MS-DOS, since cpp might not be available.
author Eli Zaretskii <eliz@gnu.org>
date Sun, 02 Sep 2001 17:27:00 +0000
parents b174db545cfd
children 695cf19ef79e d7ddb3e565de
line wrap: on
line diff
--- a/lisp/progmodes/cmacexp.el	Sun Sep 02 16:30:20 2001 +0000
+++ b/lisp/progmodes/cmacexp.el	Sun Sep 02 17:27:00 2001 +0000
@@ -108,8 +108,10 @@
   :group 'c-macro)
 
 (defcustom c-macro-preprocessor
-  ;; Cannot rely on standard directory on MS-DOS to find CPP.
-  (cond ((eq system-type 'ms-dos) "cpp -C")
+  ;; Cannot rely on standard directory on MS-DOS to find CPP.  In
+  ;; fact, cannot rely on having cpp.exe, either, in latest GCC
+  ;; versions.
+  (cond ((eq system-type 'ms-dos) "gcc -E -C -o - -")
 	;; Solaris has it in an unusual place.
 	((and (string-match "^[^-]*-[^-]*-\\(solaris\\|sunos5\\)"
 			    system-configuration)